@@ -183,8 +183,8 @@ class FireWork(FWSerializable):
     A FireWork is a workflow step and might be contain several FireTasks
     """
 
-    STATE_RANKS = {'ARCHIVED': -1, 'DEFUSED': 0, 'WAITING': 1, 'READY': 2,
-                   'RESERVED': 3, 'FIZZLED': 4, 'RUNNING': 5, 'COMPLETED': 7}
+    STATE_RANKS = {'ARCHIVED': -2, 'FIZZLED': -1, 'DEFUSED': 0, 'WAITING': 1, 'READY': 2,
+                   'RESERVED': 3,  'RUNNING': 4, 'COMPLETED': 5}
 
     def __init__(self, tasks, spec=None, name=None, launches=None,
                  archived_launches=None, state='WAITING', created_on=None,
