@@ -120,6 +120,21 @@ class LaunchPad(FWSerializable):
             'user_indices': self.user_indices,
             'wf_user_indices': self.wf_user_indices}
 
+    def update_spec(self, fw_ids, spec_document):
+        """
+        Update fireworks with a spec. Sometimes you need to modify a firework
+        in progress.
+
+        Args:
+            fw_ids: All fw_ids to modify.
+            spec_document: The spec document. Note that only modifications to
+                the spec key are allowed. So if you supply {
+                "_tasks.1.parameter": "hello"}, you are effectively modifying
+                spec._tasks.1.parameter in the actual fireworks collection.
+        """
+        mod_spec = {("spec." + k): v for k, v in spec_document.items()}
+        self.fireworks.update({'fw_id': {"$in": fw_ids}}, {"$set": mod_spec})
+
     @classmethod
     def from_dict(cls, d):
         logdir = d.get('logdir', None)
@@ -256,6 +271,27 @@ class LaunchPad(FWSerializable):
         return Workflow(fws, links_dict['links'], links_dict['name'],
                         links_dict['metadata'])
 
+    def delete_wf(self, fw_id):
+        links_dict = self.workflows.find_one({'nodes': fw_id})
+        fw_ids = links_dict["nodes"]
+        potential_launch_ids = []
+        launch_ids = []
+        for i in fw_ids:
+            fw_dict = self.fireworks.find_one({'fw_id': i})
+            potential_launch_ids += fw_dict["launches"] + fw_dict['archived_launches']
+
+        for i in potential_launch_ids:  # only remove launches if no ohter fws refer to them
+            if not self.fireworks.find_one({'$or': [{"launches": i}, {'archived_launches': i}],
+                                            'fw_id': {"$nin": fw_ids}}, {'launch_id': 1}):
+                launch_ids.append(i)
+
+        print("Remove fws %s" % fw_ids)
+        print("Remove launches %s" % launch_ids)
+        print("Removing workflow.")
+        self.launches.remove({'launch_id': {"$in": launch_ids}})
+        self.fireworks.remove({"fw_id": {"$in": fw_ids}})
+        self.workflows.remove({'nodes': fw_id})
+
     def get_wf_summary_dict(self, fw_id, mode="more"):
         """
         A much faster way to get summary information about a Workflow by
@@ -582,8 +618,9 @@ class LaunchPad(FWSerializable):
             self._refresh_wf(wf, fw_id)
 
     def detect_lostruns(self, expiration_secs=RUN_EXPIRATION_SECS, fizzle=False, rerun=False, max_runtime=None):
-        bad_launch_ids = []
-        bad_fw_ids = []
+        lost_launch_ids = []
+        lost_fw_ids = []
+        potential_lost_fw_ids = []
         now_time = datetime.datetime.utcnow()
         cutoff_timestr = (now_time - datetime.timedelta(seconds=expiration_secs)).isoformat()
         bad_launch_data = self.launches.find({'state': 'RUNNING', 'state_history': {
@@ -599,19 +636,30 @@ class LaunchPad(FWSerializable):
                     bad_launch=True
 
             if not max_runtime or bad_launch:
-                bad_launch_ids.append(ld['launch_id'])
-                bad_fw_ids.append(ld['fw_id'])
+                lost_launch_ids.append(ld['launch_id'])
+                potential_lost_fw_ids.append(ld['fw_id'])
+
+        for fw_id in potential_lost_fw_ids:  # tricky: figure out what's actually lost
+            l_ids = self.fireworks.find_one({"fw_id": fw_id}, {"launches": 1})["launches"]
+            not_lost = [x for x in l_ids if x not in lost_launch_ids]
+            if len(not_lost) == 0:  # all launches are lost - we are lost!
+                lost_fw_ids.append(fw_id)
+            else:
+                for l_id in not_lost:
+                    l_state = self.launches.find_one({"launch_id": l_id}, {"state": 1})['state']
+                    if FireWork.STATE_RANKS[l_state] > FireWork.STATE_RANKS['FIZZLED']:
+                        break
+                else:
+                    lost_fw_ids.append(fw_id)  # all Launches not lost are anyway FIZZLED / ARCHIVED
+
         if fizzle or rerun:
-            for lid in bad_launch_ids:
+            for lid in lost_launch_ids:
                 self.mark_fizzled(lid)
         if rerun:
-            for fw_id in bad_fw_ids:
-                # only rerun if the FireWork has 'FIZZLED' state. It is possible that
-                # a different Launch for the same FireWork is 'COMPLETED'
-                if self.fireworks.find_one({"fw_id": fw_id, "state": "FIZZLED"}):
-                    self.rerun_fw(fw_id)
+            for fw_id in lost_fw_ids:
+                self.rerun_fw(fw_id)
 
-        return bad_launch_ids, bad_fw_ids
+        return lost_launch_ids, lost_fw_ids
 
     def set_reservation_id(self, launch_id, reservation_id):
         m_launch = self.get_launch_by_id(launch_id)
